@@ -26,6 +26,7 @@ from onefuzztypes import (
     responses,
     webhooks,
 )
+from onefuzztypes.enums import TaskType
 from pydantic import BaseModel
 from six.moves import input  # workaround for static analysis
 
@@ -603,7 +604,7 @@ class Repro(Endpoint):
         self.logger.info("connecting to reproduction VM: %s", vm_id)
 
         if which("ssh") is None:
-            raise Exception("unable to find ssh")
+            raise Exception("unable to find ssh on local machine")
 
         def missing_os() -> Tuple[bool, str, models.Repro]:
             repro = self.get(vm_id)
@@ -617,10 +618,10 @@ class Repro(Endpoint):
 
         if repro.os == enums.OS.windows:
             if which("cdb.exe") is None:
-                raise Exception("unable to find cdb.exe")
+                raise Exception("unable to find cdb.exe on local machine")
         if repro.os == enums.OS.linux:
             if which("gdb") is None:
-                raise Exception("unable to find gdb")
+                raise Exception("unable to find gdb on local machine")
 
         def func() -> Tuple[bool, str, models.Repro]:
             repro = self.get(vm_id)
@@ -799,10 +800,16 @@ class Tasks(Endpoint):
 
         return self._req_model("POST", models.Task, data=config)
 
+    def trim_options(self, options: Optional[List[str]]) -> Optional[List[str]]:
+        # Trim any surrounding whitespace to allow users to quote multiple options with extra
+        # whitespace as a workaround for CLI argument parsing limitations. Trimming is needed
+        # to ensure that the binary eventually parses the arguments as options.
+        return [o.strip() for o in options] if options else None
+
     def create(
         self,
         job_id: UUID_EXPANSION,
-        task_type: enums.TaskType,
+        task_type: TaskType,
         target_exe: str,
         containers: List[Tuple[enums.ContainerType, primitives.Container]],
         *,
@@ -852,6 +859,13 @@ class Tasks(Endpoint):
 
         self.logger.debug("creating task: %s", task_type)
 
+        if task_type == TaskType.libfuzzer_coverage:
+            self.logger.error(
+                "The `libfuzzer_coverage` task type is deprecated. "
+                "Please migrate to the `coverage` task type."
+            )
+            raise RuntimeError("`libfuzzer_coverage` task type not supported")
+
         job_id_expanded = self._disambiguate_uuid(
             "job_id",
             job_id,
@@ -878,7 +892,7 @@ class Tasks(Endpoint):
             task=models.TaskDetails(
                 analyzer_env=analyzer_env,
                 analyzer_exe=analyzer_exe,
-                analyzer_options=analyzer_options,
+                analyzer_options=self.trim_options(analyzer_options),
                 check_asan_log=check_asan_log,
                 check_debugger=check_debugger,
                 check_retry_count=check_retry_count,
@@ -887,7 +901,7 @@ class Tasks(Endpoint):
                 duration=duration,
                 ensemble_sync_delay=ensemble_sync_delay,
                 generator_exe=generator_exe,
-                generator_options=generator_options,
+                generator_options=self.trim_options(generator_options),
                 reboot_after_setup=reboot_after_setup,
                 rename_output=rename_output,
                 stats_file=stats_file,
@@ -895,10 +909,10 @@ class Tasks(Endpoint):
                 supervisor_env=supervisor_env,
                 supervisor_exe=supervisor_exe,
                 supervisor_input_marker=supervisor_input_marker,
-                supervisor_options=supervisor_options,
+                supervisor_options=self.trim_options(supervisor_options),
                 target_env=target_env,
                 target_exe=target_exe,
-                target_options=target_options,
+                target_options=self.trim_options(target_options),
                 target_options_merge=target_options_merge,
                 target_timeout=target_timeout,
                 target_workers=target_workers,
